use DataScience
go

-- initialize dbo.datedimension table and dbo.stooq_prices 
-- based on a symbol with data for all dates (AAPL)
-- to re-run this code after the first execution
-- delete with Object Explorer or T-SQL code these table in this order:
-- dbo.stooq_prices followed by datedimension

-- read all data, except ohlcv, as strings for APPL
drop table if exists dbo.ohlcv_strings;

create table [dbo].[ohlcv_strings] (
 ticker nvarchar(10)
,period_length nvarchar(1)
,date nvarchar(8)
,time nvarchar(8)
,[open] money
,high money
,low money
,[close] money
,volume bigint
,openint nvarchar(1)
)

-- bulk insert aapl.us.txt into empty [dbo].[ohlcv_strings]
bulk insert dbo.ohlcv_strings
from 'c:\DataScienceSamples\tickers_for_modeling_with_ohlcv\aapl.us.txt'
with ( FORMAT='CSV' , FIRSTROW=2);

------------------------------------------------------------------------------------------------------------------


-- create and populate a fresh copy of dbo.datedimension
-- with a non-nullable colume and a primary key based on the column
drop table if exists dbo.datedimension

select
 [date]
,dayname
,daynumber
,monthname
,monthnumber
,year
into dbo.[datedimension]
from
(
select 
 convert(date, [date]) [date]
,datename(weekday,convert(date, [date])) dayname
,datepart(day, convert(date, [date])) daynumber
,datename(m,convert(date, [date])) monthname
,datepart(m,convert(date, [date])) monthnumber
,year(convert(date, [date])) year
from   [DataScience].[dbo].[ohlcv_strings]
where (year(date) >= 2011) and  (year(date) <= 2020)

union

select 
 convert(date, [date]) [date]
,datename(weekday,convert(date, [date])) dayname
,datepart(day, convert(date, [date])) daynumber
,datename(m,convert(date, [date])) monthname
,datepart(m,convert(date, [date])) monthnumber
,year(convert(date, [date])) year
from   [DataScience].[dbo].[ohlcv_strings]
where year(date) = 2021 and month(date) <= 6
) for_datedimension

order by date


alter table [dbo].[datedimension] ALTER COLUMN [date] date NOT NULL
alter table [dbo].[datedimension]
add constraint PK_date PRIMARY KEY (date);



-- create and populate a fresh copy of dbo.stooq_prices
-- with a non-nullable column and a primary key based on the column
drop table if exists dbo.[stooq_prices]
select
 datedimension.date [date]
,left(ticker,CHARINDEX ( '.US' , ticker)-1) symbol
,[open]
,high
,low
,[close]
,volume
into dbo.[stooq_prices]
from   [DataScience].[dbo].[ohlcv_strings]
inner join [DataScience].[dbo].[datedimension]
on [ohlcv_strings].date = [datedimension].date


alter table dbo.[stooq_prices]  WITH CHECK ADD  CONSTRAINT [fk_date] FOREIGN KEY([Date])
references [dbo].[datedimension] ([Date])
on UPDATE CASCADE
on DELETE CASCADE

---------------------------------------------------------------------------------------

truncate table [dbo].[ohlcv_strings]

-- bulk insert googl.us.txt into empty [dbo].[ohlcv_strings]
BULK INSERT dbo.ohlcv_strings
FROM 'c:\DataScienceSamples\tickers_for_modeling_with_ohlcv\googl.us.txt'
WITH ( FORMAT='CSV' , FIRSTROW=2);

-- add rows from googl.us.txt to dbo.stooq_prices
insert into dbo.stooq_prices
select
 datedimension.date [date]
,left(ticker,CHARINDEX ( '.US' , ticker)-1) symbol
,[open]
,high
,low
,[close]
,volume
from   [DataScience].[dbo].[ohlcv_strings]
inner join [DataScience].[dbo].[datedimension]
on [ohlcv_strings].date = [datedimension].date


-----------------------------------------------------------------------------------------------------------

truncate table [dbo].[ohlcv_strings]

-- bulk insert msft.us.txt into empty [dbo].[ohlcv_strings]
BULK INSERT dbo.ohlcv_strings
FROM 'c:\DataScienceSamples\tickers_for_modeling_with_ohlcv\msft.us.txt'
WITH ( FORMAT='CSV' , FIRSTROW=2);

-- add rows from msft.us.txt to dbo.stooq_prices
insert into dbo.stooq_prices
select
 datedimension.date [date]
,left(ticker,CHARINDEX ( '.US' , ticker)-1) symbol
,[open]
,high
,low
,[close]
,volume
from   [DataScience].[dbo].[ohlcv_strings]
inner join [DataScience].[dbo].[datedimension]
on [ohlcv_strings].date = [datedimension].date

---------------------------------------------------------------------------------------

truncate table [dbo].[ohlcv_strings]

-- bulk insert spxl.us.txt into empty [dbo].[ohlcv_strings]
BULK INSERT dbo.ohlcv_strings
FROM 'c:\DataScienceSamples\tickers_for_modeling_with_ohlcv\spxl.us.txt'
WITH ( FORMAT='CSV' , FIRSTROW=2);

-- add rows from spxl.us.txt to dbo.stooq_prices
insert into dbo.stooq_prices
select
 datedimension.date [date]
,left(ticker,CHARINDEX ( '.US' , ticker)-1) symbol
,[open]
,high
,low
,[close]
,volume
from   [DataScience].[dbo].[ohlcv_strings]
inner join [DataScience].[dbo].[datedimension]
on [ohlcv_strings].date = [datedimension].date

---------------------------------------------------------------------------------------

truncate table [dbo].[ohlcv_strings]

-- bulk insert tqqq.us.txt into empty [dbo].[ohlcv_strings]
BULK INSERT dbo.ohlcv_strings
FROM 'c:\DataScienceSamples\tickers_for_modeling_with_ohlcv\tqqq.us.txt'
WITH ( FORMAT='CSV' , FIRSTROW=2);

-- add rows from tqqq.us.txt to dbo.stooq_prices
insert into dbo.stooq_prices
select
 datedimension.date [date]
,left(ticker,CHARINDEX ( '.US' , ticker)-1) symbol
,[open]
,high
,low
,[close]
,volume
from   [DataScience].[dbo].[ohlcv_strings]
inner join [DataScience].[dbo].[datedimension]
on [ohlcv_strings].date = [datedimension].date

---------------------------------------------------------------------------------------


truncate table [dbo].[ohlcv_strings]

-- bulk insert udow.us.txt into empty [dbo].[ohlcv_strings]
BULK INSERT dbo.ohlcv_strings
FROM 'c:\DataScienceSamples\tickers_for_modeling_with_ohlcv\udow.us.txt'
WITH ( FORMAT='CSV' , FIRSTROW=2);

-- add rows from udow.us.txt to dbo.stooq_prices
insert into dbo.stooq_prices
select
 datedimension.date [date]
,left(ticker,CHARINDEX ( '.US' , ticker)-1) symbol
,[open]
,high
,low
,[close]
,volume
from   [DataScience].[dbo].[ohlcv_strings]
inner join [DataScience].[dbo].[datedimension]
on [ohlcv_strings].date = [datedimension].date







